@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2020 Rerrah
+ * Copyright (C) 2019-2023 Rerrah
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -26,6 +26,7 @@
 #include "audio_stream_rtaudio.hpp"
 #include <string>
 #include <vector>
+#include <QVariant>
 #include "RtAudio.h"
 
 AudioStreamRtAudio::AudioStreamRtAudio(QObject* parent)
@@ -50,10 +51,10 @@ bool AudioStreamRtAudio::initialize(uint32_t rate, uint32_t duration, uint32_t i
 	RtAudio::StreamParameters param;
 	param.nChannels = 2;
 	param.deviceId = ~0u;
-	for (unsigned int i = 0, n = audio->getDeviceCount(); i < n && param.deviceId == ~0u; ++i) {
-		RtAudio::DeviceInfo info = audio->getDeviceInfo(i);
+	for (unsigned int id : audio->getDeviceIds()) {
+		RtAudio::DeviceInfo info = audio->getDeviceInfo(id);
 		if (info.outputChannels >= 2 && info.name == deviceUtf8)
-			param.deviceId = i;
+			param.deviceId = id;
 	}
 	if (param.deviceId == ~0u)
 		param.deviceId = audio->getDefaultOutputDevice();
@@ -67,21 +68,20 @@ bool AudioStreamRtAudio::initialize(uint32_t rate, uint32_t duration, uint32_t i
 			+[](void* outputBuffer, void*, unsigned int nFrames,
 			double, RtAudioStreamStatus, void* userData) -> int {
 		auto stream = reinterpret_cast<AudioStreamRtAudio*>(userData);
-		stream->generate(static_cast<int16_t*>(outputBuffer), nFrames);
-		return 0;
+		bool result = stream->generate(static_cast<int16_t*>(outputBuffer), nFrames);
+		return result ? 0 : 1;
 	};
 
 	unsigned int bufferSize = rate * duration / 1000;
 	bool isSuccessed = false;
-	try {
-		audio->openStream(&param, nullptr, RTAUDIO_SINT16, rate, &bufferSize, callback, this, &opts);
+	const RtAudioErrorType errorType = audio->openStream(&param, nullptr, RTAUDIO_SINT16, rate, &bufferSize, callback, this, &opts);
+	if (errorType == RtAudioErrorType::RTAUDIO_NO_ERROR) {
 		if (errDetail) *errDetail = "";
 		isSuccessed = true;
 		rate = audio->getStreamSampleRate();	// Match to real rate (for ALSA)
 	}
-	catch (RtAudioError& error) {
-		error.printMessage();
-		if (errDetail) *errDetail = QString::fromStdString(error.getMessage());
+	else {
+		if (errDetail) *errDetail = QString::fromStdString(audio->getErrorText());
 	}
 
 	AudioStream::initialize(rate, duration, intrRate, backend, device);
@@ -128,8 +128,8 @@ std::vector<QString> AudioStreamRtAudio::getAvailableDevices() const
 	RtAudio* audio = audio_.get();
 	std::vector<QString> devices;
 
-	for (unsigned int i = 0, n = audio->getDeviceCount(); i < n; ++i) {
-		RtAudio::DeviceInfo info = audio->getDeviceInfo(i);
+	for (unsigned int id : audio->getDeviceIds()) {
+		RtAudio::DeviceInfo info = audio->getDeviceInfo(id);
 		if (info.outputChannels >= 2)
 			devices.push_back(QString::fromStdString(info.name));
 	}
@@ -151,10 +151,9 @@ std::vector<QString> AudioStreamRtAudio::getAvailableDevices(const QString& back
 
 	std::vector<QString> list;
 	auto a = std::make_unique<RtAudio>(api);
-	unsigned int deviceCnt = a->getDeviceCount();
-	list.reserve(deviceCnt);
-	for (unsigned int i = 0; i < deviceCnt; ++i) {
-		RtAudio::DeviceInfo info = a->getDeviceInfo(i);
+	list.reserve(a->getDeviceCount());
+	for (unsigned int id : a->getDeviceIds()) {
+		RtAudio::DeviceInfo info = a->getDeviceInfo(id);
 		if (info.outputChannels >= 2)
 			list.push_back(QString::fromStdString(info.name));
 	}
