@@ -1,26 +1,6 @@
 /*
- * Copyright (C) 2020-2021 Rerrah
- *
- * Permission is hereby granted, free of charge, to any person
- * obtaining a copy of this software and associated documentation
- * files (the "Software"), to deal in the Software without
- * restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following
- * conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
+ * SPDX-FileCopyrightText: 2020 Rerrah
+ * SPDX-License-Identifier: MIT
  */
 
 #include "change_values_in_pattern_command.hpp"
@@ -77,7 +57,7 @@ ChangeValuesInPatternCommand::ChangeValuesInPatternCommand(
 	}
 }
 
-void ChangeValuesInPatternCommand::redo()
+bool ChangeValuesInPatternCommand::redo()
 {
 	auto& sng = mod_.lock()->getSong(song_);
 	auto it = prevVals_.begin();
@@ -116,9 +96,10 @@ void ChangeValuesInPatternCommand::redo()
 			col %= Step::N_COLUMN;
 		}
 	}
+	return true;
 }
 
-void ChangeValuesInPatternCommand::undo()
+bool ChangeValuesInPatternCommand::undo()
 {
 	auto& sng = mod_.lock()->getSong(song_);
 	auto it = prevVals_.begin();
@@ -150,4 +131,5 @@ void ChangeValuesInPatternCommand::undo()
 			col %= Step::N_COLUMN;
 		}
 	}
+	return true;
 }
