@@ -1,26 +1,6 @@
 /*
- * Copyright (C) 2018-2020 Rerrah
- *
- * Permission is hereby granted, free of charge, to any person
- * obtaining a copy of this software and associated documentation
- * files (the "Software"), to deal in the Software without
- * restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following
- * conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
+ * SPDX-FileCopyrightText: 2018 Rerrah
+ * SPDX-License-Identifier: MIT
  */
 
 #include "set_effect_value_to_step_command.hpp"
@@ -44,7 +24,7 @@ SetEffectValueToStepCommand::SetEffectValueToStepCommand(
 	prevVal_ = command_utils::getStep(mod, songNum, trackNum, orderNum, stepNum).getEffectValue(n);
 }
 
-void SetEffectValueToStepCommand::redo()
+bool SetEffectValueToStepCommand::redo()
 {
 	int value;
 	switch (ctrl_) {
@@ -60,12 +40,14 @@ void SetEffectValueToStepCommand::redo()
 		break;
 	}
 	command_utils::getStep(mod_, song_, track_, order_, step_).setEffectValue(n_, value);
+	return true;
 }
 
-void SetEffectValueToStepCommand::undo()
+bool SetEffectValueToStepCommand::undo()
 {
 	command_utils::getStep(mod_, song_, track_, order_, step_).setEffectValue(n_, prevVal_);
 	isSecondEntry_ = true;	// Forced complete
+	return true;
 }
 
 bool SetEffectValueToStepCommand::mergeWith(const AbstractCommand* other)
