@@ -91,12 +91,15 @@ void EffectListDialog::addRow(EffectType effect, std::unordered_set<SoundSource>
 	int row = ui->tableWidget->rowCount();
 	ui->tableWidget->insertRow(row);
 	ui->tableWidget->setItem(row, 0, new QTableWidgetItem(effect_desc::getEffectFormat(effect)));
-	ui->tableWidget->setRowHeight(row, ui->tableWidget->horizontalHeader()->height());
-	QString typeStr("");
-	if (types.count(SoundSource::FM)) typeStr += "FM";
-	if (types.count(SoundSource::SSG)) typeStr = typeStr + (typeStr.isEmpty() ? "" : ", ") + "SSG";
-	if (types.count(SoundSource::RHYTHM)) typeStr = typeStr + (typeStr.isEmpty() ? "" : ", ") + tr("Rhythm");
-	if (types.count(SoundSource::ADPCM)) typeStr = typeStr + (typeStr.isEmpty() ? "" : ", ") + "ADPCM";
-	ui->tableWidget->setItem(row, 1, new QTableWidgetItem(typeStr));
-	ui->tableWidget->setItem(row, 2, new QTableWidgetItem(effect_desc::getEffectDescription(effect)));
+    ui->tableWidget->setRowHeight(row, ui->tableWidget->horizontalHeader()->height());
+    auto trackTypes = {
+        SoundSource::FM, SoundSource::SSG, SoundSource::RHYTHM, SoundSource::ADPCM
+    };
+    int col = 1;
+    for (const auto trackType : trackTypes){
+        ui->tableWidget->setItem(row, col, new QTableWidgetItem(QString(types.count(trackType) ? "✓" : "")));
+        ui->tableWidget->resizeColumnToContents(col);
+        col++;
+    }
+    ui->tableWidget->setItem(row, col, new QTableWidgetItem(effect_desc::getEffectDescription(effect)));
 }
