@@ -108,7 +108,7 @@ FMOperatorTable::FMOperatorTable(QWidget *parent) :
 		if (!isIgnoreEvent_) emit operatorValueChanged(Ui::FMOperatorParameter::SSGEG, value);
 	});
 
-	ui->envFrame->installEventFilter(this);
+	ui->envFrame->viewport()->installEventFilter(this);
 }
 
 FMOperatorTable::~FMOperatorTable()
@@ -204,34 +204,43 @@ QString FMOperatorTable::toString() const
 
 bool FMOperatorTable::eventFilter(QObject* obj, QEvent* event)
 {
-	if (obj == ui->envFrame) {
+	QWidget * viewport = ui->envFrame->viewport();
+	if (obj == viewport) {
 		if (event->type() == QEvent::Paint) {
-			QPainter painter(ui->envFrame);
-			painter.eraseRect(ui->envFrame->rect());
-			painter.drawPixmap(ui->envFrame->rect(), envmap_, envmap_.rect());
+			QPainter painter(viewport);
+			painter.eraseRect(viewport->rect());
+			painter.drawImage(viewport->rect(), envmap_, envmap_.rect());
+
+			// Don't call event->accept(), because isAccepted() is already true.
+			// Return true to stop QAbstractScrollArea from painting(?) on the viewport.
+			return true;
 		}
 	}
 
 	return false;
 }
 
-void FMOperatorTable::showEvent(QShowEvent* event)
+void FMOperatorTable::showEvent(QShowEvent*)
 {
-	Q_UNUSED(event)
 	resizeGraph();
 	repaintGraph();
 }
 
-void FMOperatorTable::resizeEvent(QResizeEvent* event)
+void FMOperatorTable::resizeEvent(QResizeEvent*)
 {
-	Q_UNUSED(event)
 	resizeGraph();
 	repaintGraph();
 }
 
 void FMOperatorTable::resizeGraph()
 {
-	envmap_ = QPixmap(ui->envFrame->size());
+	QWidget * viewport = ui->envFrame->viewport();
+
+	// Making envmap_ a QImage and using an ARGB pixel format ensures that when we fill
+	// it with instFMEnvBackColor (transparent), the image supports transparency.
+	// On Windows, QPixmap instead defaults to Format_RGB32 which has no alpha channel.
+
+	envmap_ = QImage(viewport->size(), QImage::Format_ARGB32_Premultiplied);
 	xr_ = (envmap_.width() - (ENV_LINE_W_ + 1) * 2.) / ENV_W_;
 	yr_ = (envmap_.height() - (ENV_LINE_W_ + 1) * 2.) / ENV_H_;
 }
@@ -427,12 +436,11 @@ void FMOperatorTable::repaintGraph()
 		}
 	}
 
-	ui->envFrame->repaint();
+	ui->envFrame->viewport()->repaint();
 }
 
-void FMOperatorTable::on_ssgegCheckBox_stateChanged(int arg1)
+void FMOperatorTable::on_ssgegCheckBox_stateChanged(int)
 {
-	Q_UNUSED(arg1)
 	if (ui->ssgegCheckBox->isChecked()) {
 		ui->ssgegSlider->setEnabled(true);
 		if (!isIgnoreEvent_) emit operatorValueChanged(Ui::FMOperatorParameter::SSGEG, ui->ssgegSlider->value());
