@@ -33,7 +33,7 @@
 #include <QShowEvent>
 #include <QResizeEvent>
 #include <QString>
-#include <QPixmap>
+#include <QImage>
 #include <QPainter>
 #include <QPointF>
 #include "gui/labeled_vertical_slider.hpp"
@@ -68,8 +68,8 @@ public:
 
 protected:
 	bool eventFilter(QObject* obj, QEvent* event) override;
-	void showEvent(QShowEvent* event) override;
-	void resizeEvent(QResizeEvent* event) override;
+	void showEvent(QShowEvent*) override;
+	void resizeEvent(QResizeEvent*) override;
 
 signals:
 	void operatorValueChanged(Ui::FMOperatorParameter param, int value);
@@ -81,7 +81,7 @@ signals:
 	void pasteOperatorPressed(int num);
 
 private slots:
-	void on_ssgegCheckBox_stateChanged(int arg1);
+	void on_ssgegCheckBox_stateChanged(int);
 	void on_groupBox_toggled(bool arg1);
 	void on_groupBox_customContextMenuRequested(const QPoint &pos);
 
@@ -95,7 +95,7 @@ private:
 	bool isIgnoreEvent_;
 
 	// Envelope graph
-	QPixmap envmap_;
+	QImage envmap_;
 	static constexpr int ENV_H_ = 127;
 	static constexpr int ENV_W_ = 200;
 	static constexpr int SSGEG_H_ = 35;
