@@ -1,26 +1,6 @@
 /*
- * Copyright (C) 2018-2022 Rerrah
- *
- * Permission is hereby granted, free of charge, to any person
- * obtaining a copy of this software and associated documentation
- * files (the "Software"), to deal in the Software without
- * restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following
- * conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
+ * SPDX-FileCopyrightText: 2018 Rerrah
+ * SPDX-License-Identifier: MIT
  */
 
 #ifndef PATTERN_EDITOR_PANEL_HPP
@@ -47,6 +27,7 @@
 #include "bamboo_tracker.hpp"
 #include "configuration.hpp"
 #include "song.hpp"
+#include "vector_2d.hpp"
 #include "gui/pattern_editor/pattern_position.hpp"
 #include "gui/color_palette.hpp"
 
@@ -300,11 +281,9 @@ private:
 	void pasteMixCopiedCells(const PatternPosition& cursorPos);
 	void pasteOverwriteCopiedCells(const PatternPosition& cursorPos);
 	void pasteInsertCopiedCells(const PatternPosition& cursorPos);
-	using PatternCells = std::vector<std::vector<std::string>>;
-	PatternCells decodeCells(QString str, int& startCol);
 	PatternPosition getPasteLeftAbovePosition(
 			int pasteCol, const PatternPosition& cursorPos, size_t cellW) const;
-	PatternCells compandPasteCells(const PatternPosition& laPos, const PatternCells& cells);
+	Vector2d<std::string> makeCopiedCellsForPasteFull(const PatternPosition& laPos, const Vector2d<std::string>& cells);
 
 	void transposeNote(const PatternPosition& startPos, const PatternPosition& endPos, int semitone);
 	void changeValuesInPattern(const PatternPosition& startPos, const PatternPosition& endPos, int value);
